(function (factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define([], factory);
    } else if (typeof exports === 'object') {
        // Node. Does not work with strict CommonJS, but
        // only CommonJS-like enviroments that support module.exports,
        // like Node.
        module.exports = factory();
    } else {
        // Browser globals
        this.tdigest = factory();
    }
}(function () {
    var global = this, define;
    function _require(id) {
        var module = _require.cache[id];
        if (!module) {
            var exports = {};
            module = _require.cache[id] = {
                id: id,
                exports: exports
            };
            _require.modules[id].call(exports, module, exports);
        }
        return module.exports;
    }
    _require.cache = [];
    _require.modules = [
        function (module, exports) {
            module.exports = {
                RBTree: _require(2),
                BinTree: _require(1)
            };
        },
        function (module, exports) {
            var TreeBase = _require(3);
            function Node(data) {
                this.data = data;
                this.left = null;
                this.right = null;
            }
            Node.prototype.get_child = function (dir) {
                return dir ? this.right : this.left;
            };
            Node.prototype.set_child = function (dir, val) {
                if (dir) {
                    this.right = val;
                } else {
                    this.left = val;
                }
            };
            function BinTree(comparator) {
                this._root = null;
                this._comparator = comparator;
                this.size = 0;
            }
            BinTree.prototype = new TreeBase();    // returns true if inserted, false if duplicate
            // returns true if inserted, false if duplicate
            BinTree.prototype.insert = function (data) {
                if (this._root === null) {
                    // empty tree
                    this._root = new Node(data);
                    this.size++;
                    return true;
                }
                var dir = 0;    // setup
                // setup
                var p = null;    // parent
                // parent
                var node = this._root;    // search down
                // search down
                while (true) {
                    if (node === null) {
                        // insert new node at the bottom
                        node = new Node(data);
                        p.set_child(dir, node);
                        ret = true;
                        this.size++;
                        return true;
                    }    // stop if found
                    // stop if found
                    if (this._comparator(node.data, data) === 0) {
                        return false;
                    }
                    dir = this._comparator(node.data, data) < 0;    // update helpers
                    // update helpers
                    p = node;
                    node = node.get_child(dir);
                }
            };    // returns true if removed, false if not found
            // returns true if removed, false if not found
            BinTree.prototype.remove = function (data) {
                if (this._root === null) {
                    return false;
                }
                var head = new Node(undefined);    // fake tree root
                // fake tree root
                var node = head;
                node.right = this._root;
                var p = null;    // parent
                // parent
                var found = null;    // found item
                // found item
                var dir = 1;
                while (node.get_child(dir) !== null) {
                    p = node;
                    node = node.get_child(dir);
                    var cmp = this._comparator(data, node.data);
                    dir = cmp > 0;
                    if (cmp === 0) {
                        found = node;
                    }
                }
                if (found !== null) {
                    found.data = node.data;
                    p.set_child(p.right === node, node.get_child(node.left === null));
                    this._root = head.right;
                    this.size--;
                    return true;
                } else {
                    return false;
                }
            };
            module.exports = BinTree;
        },
        function (module, exports) {
            var TreeBase = _require(3);
            function Node(data) {
                this.data = data;
                this.left = null;
                this.right = null;
                this.red = true;
            }
            Node.prototype.get_child = function (dir) {
                return dir ? this.right : this.left;
            };
            Node.prototype.set_child = function (dir, val) {
                if (dir) {
                    this.right = val;
                } else {
                    this.left = val;
                }
            };
            function RBTree(comparator) {
                this._root = null;
                this._comparator = comparator;
                this.size = 0;
            }
            RBTree.prototype = new TreeBase();    // returns true if inserted, false if duplicate
            // returns true if inserted, false if duplicate
            RBTree.prototype.insert = function (data) {
                var ret = false;
                if (this._root === null) {
                    // empty tree
                    this._root = new Node(data);
                    ret = true;
                    this.size++;
                } else {
                    var head = new Node(undefined);    // fake tree root
                    // fake tree root
                    var dir = 0;
                    var last = 0;    // setup
                    // setup
                    var gp = null;    // grandparent
                    // grandparent
                    var ggp = head;    // grand-grand-parent
                    // grand-grand-parent
                    var p = null;    // parent
                    // parent
                    var node = this._root;
                    ggp.right = this._root;    // search down
                    // search down
                    while (true) {
                        if (node === null) {
                            // insert new node at the bottom
                            node = new Node(data);
                            p.set_child(dir, node);
                            ret = true;
                            this.size++;
                        } else if (is_red(node.left) && is_red(node.right)) {
                            // color flip
                            node.red = true;
                            node.left.red = false;
                            node.right.red = false;
                        }    // fix red violation
                        // fix red violation
                        if (is_red(node) && is_red(p)) {
                            var dir2 = ggp.right === gp;
                            if (node === p.get_child(last)) {
                                ggp.set_child(dir2, single_rotate(gp, !last));
                            } else {
                                ggp.set_child(dir2, double_rotate(gp, !last));
                            }
                        }
                        var cmp = this._comparator(node.data, data);    // stop if found
                        // stop if found
                        if (cmp === 0) {
                            break;
                        }
                        last = dir;
                        dir = cmp < 0;    // update helpers
                        // update helpers
                        if (gp !== null) {
                            ggp = gp;
                        }
                        gp = p;
                        p = node;
                        node = node.get_child(dir);
                    }    // update root
                    // update root
                    this._root = head.right;
                }    // make root black
                // make root black
                this._root.red = false;
                return ret;
            };    // returns true if removed, false if not found
            // returns true if removed, false if not found
            RBTree.prototype.remove = function (data) {
                if (this._root === null) {
                    return false;
                }
                var head = new Node(undefined);    // fake tree root
                // fake tree root
                var node = head;
                node.right = this._root;
                var p = null;    // parent
                // parent
                var gp = null;    // grand parent
                // grand parent
                var found = null;    // found item
                // found item
                var dir = 1;
                while (node.get_child(dir) !== null) {
                    var last = dir;    // update helpers
                    // update helpers
                    gp = p;
                    p = node;
                    node = node.get_child(dir);
                    var cmp = this._comparator(data, node.data);
                    dir = cmp > 0;    // save found node
                    // save found node
                    if (cmp === 0) {
                        found = node;
                    }    // push the red node down
                    // push the red node down
                    if (!is_red(node) && !is_red(node.get_child(dir))) {
                        if (is_red(node.get_child(!dir))) {
                            var sr = single_rotate(node, dir);
                            p.set_child(last, sr);
                            p = sr;
                        } else if (!is_red(node.get_child(!dir))) {
                            var sibling = p.get_child(!last);
                            if (sibling !== null) {
                                if (!is_red(sibling.get_child(!last)) && !is_red(sibling.get_child(last))) {
                                    // color flip
                                    p.red = false;
                                    sibling.red = true;
                                    node.red = true;
                                } else {
                                    var dir2 = gp.right === p;
                                    if (is_red(sibling.get_child(last))) {
                                        gp.set_child(dir2, double_rotate(p, last));
                                    } else if (is_red(sibling.get_child(!last))) {
                                        gp.set_child(dir2, single_rotate(p, last));
                                    }    // ensure correct coloring
                                    // ensure correct coloring
                                    var gpc = gp.get_child(dir2);
                                    gpc.red = true;
                                    node.red = true;
                                    gpc.left.red = false;
                                    gpc.right.red = false;
                                }
                            }
                        }
                    }
                }    // replace and remove if found
                // replace and remove if found
                if (found !== null) {
                    found.data = node.data;
                    p.set_child(p.right === node, node.get_child(node.left === null));
                    this.size--;
                }    // update root and make it black
                // update root and make it black
                this._root = head.right;
                if (this._root !== null) {
                    this._root.red = false;
                }
                return found !== null;
            };
            function is_red(node) {
                return node !== null && node.red;
            }
            function single_rotate(root, dir) {
                var save = root.get_child(!dir);
                root.set_child(!dir, save.get_child(dir));
                save.set_child(dir, root);
                root.red = true;
                save.red = false;
                return save;
            }
            function double_rotate(root, dir) {
                root.set_child(!dir, single_rotate(root.get_child(!dir), !dir));
                return single_rotate(root, dir);
            }
            module.exports = RBTree;
        },
        function (module, exports) {
            function TreeBase() {
            }    // removes all nodes from the tree
            // removes all nodes from the tree
            TreeBase.prototype.clear = function () {
                this._root = null;
                this.size = 0;
            };    // returns node data if found, null otherwise
            // returns node data if found, null otherwise
            TreeBase.prototype.find = function (data) {
                var res = this._root;
                while (res !== null) {
                    var c = this._comparator(data, res.data);
                    if (c === 0) {
                        return res.data;
                    } else {
                        res = res.get_child(c > 0);
                    }
                }
                return null;
            };    // returns iterator to node if found, null otherwise
            // returns iterator to node if found, null otherwise
            TreeBase.prototype.findIter = function (data) {
                var res = this._root;
                var iter = this.iterator();
                while (res !== null) {
                    var c = this._comparator(data, res.data);
                    if (c === 0) {
                        iter._cursor = res;
                        return iter;
                    } else {
                        iter._ancestors.push(res);
                        res = res.get_child(c > 0);
                    }
                }
                return null;
            };    // Returns an interator to the tree node at or immediately after the item
            // Returns an interator to the tree node at or immediately after the item
            TreeBase.prototype.lowerBound = function (item) {
                var cur = this._root;
                var iter = this.iterator();
                var cmp = this._comparator;
                while (cur !== null) {
                    var c = cmp(item, cur.data);
                    if (c === 0) {
                        iter._cursor = cur;
                        return iter;
                    }
                    iter._ancestors.push(cur);
                    cur = cur.get_child(c > 0);
                }
                for (var i = iter._ancestors.length - 1; i >= 0; --i) {
                    cur = iter._ancestors[i];
                    if (cmp(item, cur.data) < 0) {
                        iter._cursor = cur;
                        iter._ancestors.length = i;
                        return iter;
                    }
                }
                iter._ancestors.length = 0;
                return iter;
            };    // Returns an interator to the tree node immediately after the item
            // Returns an interator to the tree node immediately after the item
            TreeBase.prototype.upperBound = function (item) {
                var iter = this.lowerBound(item);
                var cmp = this._comparator;
                while (cmp(iter.data(), item) === 0) {
                    iter.next();
                }
                return iter;
            };    // returns null if tree is empty
            // returns null if tree is empty
            TreeBase.prototype.min = function () {
                var res = this._root;
                if (res === null) {
                    return null;
                }
                while (res.left !== null) {
                    res = res.left;
                }
                return res.data;
            };    // returns null if tree is empty
            // returns null if tree is empty
            TreeBase.prototype.max = function () {
                var res = this._root;
                if (res === null) {
                    return null;
                }
                while (res.right !== null) {
                    res = res.right;
                }
                return res.data;
            };    // returns a null iterator
                  // call next() or prev() to point to an element
            // returns a null iterator
            // call next() or prev() to point to an element
            TreeBase.prototype.iterator = function () {
                return new Iterator(this);
            };    // calls cb on each node's data, in order
            // calls cb on each node's data, in order
            TreeBase.prototype.each = function (cb) {
                var it = this.iterator(), data;
                while ((data = it.next()) !== null) {
                    cb(data);
                }
            };    // calls cb on each node's data, in reverse order
            // calls cb on each node's data, in reverse order
            TreeBase.prototype.reach = function (cb) {
                var it = this.iterator(), data;
                while ((data = it.prev()) !== null) {
                    cb(data);
                }
            };
            function Iterator(tree) {
                this._tree = tree;
                this._ancestors = [];
                this._cursor = null;
            }
            Iterator.prototype.data = function () {
                return this._cursor !== null ? this._cursor.data : null;
            };    // if null-iterator, returns first node
                  // otherwise, returns next node
            // if null-iterator, returns first node
            // otherwise, returns next node
            Iterator.prototype.next = function () {
                if (this._cursor === null) {
                    var root = this._tree._root;
                    if (root !== null) {
                        this._minNode(root);
                    }
                } else {
                    if (this._cursor.right === null) {
                        // no greater node in subtree, go up to parent
                        // if coming from a right child, continue up the stack
                        var save;
                        do {
                            save = this._cursor;
                            if (this._ancestors.length) {
                                this._cursor = this._ancestors.pop();
                            } else {
                                this._cursor = null;
                                break;
                            }
                        } while (this._cursor.right === save);
                    } else {
                        // get the next node from the subtree
                        this._ancestors.push(this._cursor);
                        this._minNode(this._cursor.right);
                    }
                }
                return this._cursor !== null ? this._cursor.data : null;
            };    // if null-iterator, returns last node
                  // otherwise, returns previous node
            // if null-iterator, returns last node
            // otherwise, returns previous node
            Iterator.prototype.prev = function () {
                if (this._cursor === null) {
                    var root = this._tree._root;
                    if (root !== null) {
                        this._maxNode(root);
                    }
                } else {
                    if (this._cursor.left === null) {
                        var save;
                        do {
                            save = this._cursor;
                            if (this._ancestors.length) {
                                this._cursor = this._ancestors.pop();
                            } else {
                                this._cursor = null;
                                break;
                            }
                        } while (this._cursor.left === save);
                    } else {
                        this._ancestors.push(this._cursor);
                        this._maxNode(this._cursor.left);
                    }
                }
                return this._cursor !== null ? this._cursor.data : null;
            };
            Iterator.prototype._minNode = function (start) {
                while (start.left !== null) {
                    this._ancestors.push(start);
                    start = start.left;
                }
                this._cursor = start;
            };
            Iterator.prototype._maxNode = function (start) {
                while (start.right !== null) {
                    this._ancestors.push(start);
                    start = start.right;
                }
                this._cursor = start;
            };
            module.exports = TreeBase;
        },
        function (module, exports) {
            var RBTree = _require(0).RBTree;
            function TDigest(delta, K, CX) {
                // allocate a TDigest structure.
                //
                // delta is the compression factor, related to the max fraction of
                // counts that can be owned by one centroid (bigger means more
                // compression).
                //
                // K is a size threshold that triggers recompression as the TDigest
                // grows during input.  (Set it to 0 to disable automatic recompression)
                //
                // CX specifies how often to update cached cumulative totals used
                // for quantile estimation during ingest (see cumulate()).  Set to
                // 0 to use exact quantiles for each new point.
                //
                this.delta = delta === undefined ? 0.01 : delta;
                this.K = K === undefined ? 25 : K;
                this.CX = CX === undefined ? 1.1 : CX;
                this.centroids = new RBTree(compare_centroid_means);
                this.nreset = 0;
                this.reset();
            }
            TDigest.prototype.reset = function () {
                // prepare to digest new points.
                //
                this.centroids.clear();
                this.n = 0;
                this.nreset += 1;
                this.last_cumulate = 0;
            };
            TDigest.prototype.size = function () {
                return this.centroids.size;
            };
            TDigest.prototype.toArray = function (everything) {
                // return {mean,n} of centroids as an array ordered by mean.
                //
                var result = [];
                if (everything) {
                    this._cumulate(true);    // be sure cumns are exact
                    // be sure cumns are exact
                    this.centroids.each(function (c) {
                        result.push(c);
                    });
                } else {
                    this.centroids.each(function (c) {
                        result.push({
                            mean: c.mean,
                            n: c.n
                        });
                    });
                }
                return result;
            };
            TDigest.prototype.summary = function () {
                var s = [
                        'approximating ' + this.n + ' samples using ' + this.size() + ' centroids, delta=' + this.delta + ', CX=' + this.CX,
                        'min = ' + this.percentile(0),
                        'Q1  = ' + this.percentile(0.25),
                        'Q2  = ' + this.percentile(0.5),
                        'Q3  = ' + this.percentile(0.75),
                        'max = ' + this.percentile(1)
                    ];
                return s.join('\n');
            };
            function compare_centroid_means(a, b) {
                // order two centroids by mean.
                //
                if (a === null) {
                    // XXX super-narrow workaround for https://github.com/vadimg/js_bintrees/pull/14
                    return NaN;
                }
                return a.mean - b.mean;
            }
            function compare_centroid_cumns(a, b) {
                // order two centroids by cumn. 
                //
                if (a === null) {
                    // XXX super-narrow workaround for https://github.com/vadimg/js_bintrees/pull/14
                    return NaN;
                }
                return a.cumn - b.cumn;
            }
            function pop_random(choices) {
                // remove and return an item randomly chosen from the array of choices
                // (mutates choices)
                //
                var idx = Math.floor(Math.random() * choices.length);
                return choices.splice(idx, 1)[0];
            }
            TDigest.prototype.push = function (x, n) {
                // incorporate value or array of values x, having count n into the
                // TDigest. n defaults to 1.
                //
                n = n || 1;
                x = Array.isArray(x) ? x : [x];
                for (var i = 0; i < x.length; i++) {
                    this._digest(x[i], n);
                }
            };
            TDigest.prototype.push_centroid = function (c) {
                // incorporate centroid or array of centroids c
                //
                c = Array.isArray(c) ? c : [c];
                for (var i = 0; i < c.length; i++) {
                    this._digest(c[i].mean, c[i].n);
                }
            };
            TDigest.prototype._cumulate = function (exact) {
                // update cumulative counts for each centroid
                //
                // exact: falsey means only cumulate after sufficient
                // growth. During ingest, these counts are used as quantile
                // estimates, and they work well even when somewhat out of
                // date. (this is a departure from the publication, you may set CX
                // to 0 to disable).
                //
                if (this.n === this.last_cumulate || !exact && this.CX && this.CX > this.n / this.last_cumulate) {
                    return;
                }
                var cumn = 0;
                this.centroids.each(function (c) {
                    c.cumn = cumn + c.n / 2;    // at the mean, we've accumulated half the n.
                    // at the mean, we've accumulated half the n.
                    cumn += c.n;
                });
                this.n = this.last_cumulate = cumn;
            };
            TDigest.prototype.find_nearest = function (x) {
                // find the centroid closest to x. The assumption of
                // unique means and a unique nearest centroid departs from the
                // paper, see _digest() below
                //
                if (this.size() === 0) {
                    return null;
                }
                var iter = this.centroids.upperBound({ mean: x });    // x < iter || iter==null
                // x < iter || iter==null
                var c = iter.data() === null ? iter.prev() : iter.data();    // walk backwards looking for closest centroid.
                // walk backwards looking for closest centroid.
                var nearest = c;
                var mindist = Math.abs(nearest.mean - x);
                var dx;
                while ((c = iter.prev()) && (dx = Math.abs(c.mean - x)) < mindist) {
                    mindist = dx;
                    nearest = c;
                }
                return nearest;
            };
            TDigest.prototype._new_centroid = function (x, n, cumn) {
                // create and insert a new centroid into the digest (don't update
                // cumulatives).
                //
                var c = {
                        mean: x,
                        n: n,
                        cumn: cumn
                    };
                this.centroids.insert(c);
                this.n += n;
                return c;
            };
            TDigest.prototype._addweight = function (nearest, x, n) {
                // add weight at location x to nearest centroid.  adding x to
                // nearest will not shift its relative position in the tree and
                // require reinsertion.
                //
                var newmean = nearest.mean + n * (x - nearest.mean) / (nearest.n + n);
                nearest.mean = newmean;
                nearest.n += n;
                nearest.cumn += n / 2;
                this.n += n;
            };
            TDigest.prototype._digest = function (x, n) {
                // incorporate value x, having count n into the TDigest.
                //
                var min = this.centroids.min();
                var max = this.centroids.max();
                if (this.size() === 0 || x < min.mean) {
                    this._new_centroid(x, n, n / 2);    // first or new min point
                } else // first or new min point
                if (max.mean < x) {
                    this._new_centroid(x, n, this.n + n / 2);    // new max point
                } else
                    // new max point
                    {
                        var nearest = this.find_nearest(x);
                        if (nearest.mean === x) {
                            // accumulate exact matches into the centroid without
                            // limit. this is a departure from the paper, made so that
                            // centroid means remain unique and code can be simple.
                            this._addweight(nearest, x, n);
                            return;
                        }
                        var p = nearest.cumn / this.n;
                        var max_n = Math.floor(4 * this.n * this.delta * p * (1 - p));
                        if (nearest != min && nearest != max && max_n - nearest.n >= n) {
                            // if there's not room for all of n, don't bother merging
                            // some of it into nearest, as we'll have to make a new
                            // centroid anyway for the remainder (departure from the
                            // paper).
                            this._addweight(nearest, x, n);
                        } else {
                            // create a new centroid at x
                            this._new_centroid(x, n, nearest.cumn);    // approximate cumn
                        }
                        // approximate cumn
                        this._cumulate(false);
                    }
                this._cumulate(false);
                if (this.K && this.size() > this.K / this.delta) {
                    // re-process the centroids and hope for some compression.
                    this.compress();
                }
            };
            TDigest.prototype.bound_mean = function (x) {
                // find centroids lower and upper such that lower.mean < x <
                // upper.mean or lower.mean === x === upper.mean. Don't call
                // this for x out of bounds.
                //
                var iter = this.centroids.upperBound({ mean: x });    // x < iter
                // x < iter
                var lower = iter.prev();    // lower <= x
                // lower <= x
                var upper = lower.mean === x ? lower : iter.next();
                return [
                    lower,
                    upper
                ];
            };
            TDigest.prototype.quantile = function (x) {
                // return approximate quantile (0..1) for data value x.  Beware
                // that boundary values will report half their centroid weight
                // inward from 0/1. Data values outside the observed range return 0/1
                //
                // this triggers cumulate() if cumn's are out of date.
                //
                if (this.size() === 0) {
                    return NaN;
                } else if (x < this.centroids.min().mean) {
                    return 0;
                } else if (x > this.centroids.max().mean) {
                    return 1;
                }    // find centroids that bracket x and interpolate x's cumn from
                     // their cumn's.
                // find centroids that bracket x and interpolate x's cumn from
                // their cumn's.
                var bound = this.bound_mean(x);
                var lower = bound[0], upper = bound[1];
                this._cumulate(true);    // be sure cumns are exact
                // be sure cumns are exact
                var cumn = lower.cumn;
                if (lower !== upper) {
                    cumn += (upper.cumn - lower.cumn) * (x - lower.mean) / (upper.mean - lower.mean);
                }
                return cumn / this.n;
            };
            TDigest.prototype.quantiles = function (xlist) {
                // return a list of quantiles for the values in xlist
                return xlist.map(this.quantile, this);
            };
            TDigest.prototype.bound_cumn = function (cumn) {
                // find centroids lower and upper such that lower.cumn < x <
                // upper.cumn or lower.cumn === x === upper.cumn. Don't call
                // this for cumn out of bounds.
                //
                // XXX because mean and cumn give rise to the same sort order
                // (up to identical means), use the mean rbtree for our cumn search.
                this.centroids._comparator = compare_centroid_cumns;
                var iter = this.centroids.upperBound({ cumn: cumn });    // cumn < iter 
                // cumn < iter 
                this.centroids._comparator = compare_centroid_means;
                var lower = iter.prev();    // lower <= cumn
                // lower <= cumn
                var upper = lower.cumn === cumn ? lower : iter.next();
                return [
                    lower,
                    upper
                ];
            };
            TDigest.prototype.percentile = function (p) {
                // return the approximate data value q at the specified percentile (0..1).
                // also known as the inverse cdf.
                //
                // this triggers cumulate() if cumn's are out of date.
                //
                this._cumulate(true);    // be sure cumns are exact
                // be sure cumns are exact
                var cumn = p * this.n;
                var min = this.centroids.min();
                var max = this.centroids.max();
                if (this.size() === 0) {
                    return NaN;
                } else if (cumn <= min.cumn) {
                    return min.mean;
                } else if (cumn >= max.cumn) {
                    return max.mean;
                }    // find centroids whose cumns bracket cumn, then interpolate x
                     // from their means. 
                // find centroids whose cumns bracket cumn, then interpolate x
                // from their means. 
                var bound = this.bound_cumn(cumn);
                var lower = bound[0], upper = bound[1];
                var q = lower.mean;
                if (lower !== upper) {
                    q += (upper.mean - lower.mean) * (cumn - lower.cumn) / (upper.cumn - lower.cumn);
                }
                return q;
            };
            TDigest.prototype.percentiles = function (plist) {
                // return a list of percentile values for the percentages in plist
                return plist.map(this.percentile, this);
            };
            TDigest.prototype.compress = function () {
                // TDigests experience worst case compression (none) when input
                // increases monotonically.  Improve on any bad luck by
                // reconsuming digest centroids as if they were weighted points
                // while shuffling their order (and hope for the best).
                //
                if (this.compressing) {
                    return;
                }
                var points = this.toArray();
                this.reset();
                this.compressing = true;
                this.push_centroid(points.shift());    // min
                // min
                this.push_centroid(points.pop());    // max
                // max
                while (points.length > 0) {
                    this.push_centroid(pop_random(points));
                }
                this._cumulate(true);
                this.compressing = false;
            };
            module.exports = { 'TDigest': TDigest };
        }
    ];
    return _require(4);
}));